import requests
from vocode.models.agent import InformationRetrievalAgentConfig, LLMAgentConfig
from vocode.models.telephony import CallEntity, CreateCallRequest
import os
from dotenv import load_dotenv

load_dotenv()

BASE_URL = os.environ.get("BASE_URL")


def create_call(request: CreateCallRequest):
    request_data = request.dict()

    url = f"http://{BASE_URL}/create_outbound_call"
    headers = {"Content-Type": "application/json"}

    response = requests.post(url, headers=headers, json=request_data)
    return response.status_code


def create_information_retrieval_call(
    recipient: CallEntity,
    caller: CallEntity,
    goal_description: str,
    fields: list[str] = None,
):
    agent_config = InformationRetrievalAgentConfig(
        recipient_descriptor=recipient.descriptor,
        caller_descriptor=caller.descriptor,
        goal_description=goal_description,
        fields=fields,
    )

    return create_call(
        CreateCallRequest(
            recipient=recipient,
            caller=caller,
            agent_config=agent_config,
        )
    )



from typing import Optional
from enum import Enum
from .model import TypedModel


class AgentType(str, Enum):
    BASE = "base"
    LLM = "llm"
    CHAT_GPT = "chat_gpt"
    ECHO = "echo"
    INFORMATION_RETRIEVAL = "information_retrieval"


class AgentConfig(TypedModel, type=AgentType.BASE):
    initial_message: Optional[str] = None


class LLMAgentConfig(AgentConfig, type=AgentType.LLM):
    prompt_preamble: str
    expected_first_prompt: Optional[str] = None

class ChatGPTAgentConfig(AgentConfig, type=AgentType.CHAT_GPT):
    prompt_preamble: str
    expected_first_prompt: Optional[str] = None

class InformationRetrievalAgentConfig(
    AgentConfig, type=AgentType.INFORMATION_RETRIEVAL
):
    recipient_descriptor: str
    caller_descriptor: str
    goal_description: str
    fields: list[str]
    # TODO: add fields for IVR, voicemail


class EchoAgentConfig(AgentConfig, type=AgentType.ECHO):
    pass



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['vocode', 'vocode.input_device', 'vocode.models', 'vocode.output_device']

package_data = \
{'': ['*']}

install_requires = \
['pydantic==1.10.5',
 'python-dotenv==0.21.1',
 'typing-extensions==4.5.0',
 'websockets==10.4']

extras_require = \
{'pyaudio': ['pyaudio==0.2.13']}

setup_kwargs = {
    'name': 'vocode',
    'version': '0.1.2',
    'description': 'The all-in-one voice SDK',
    'long_description': '# vocode-python-sdk\n\n```bash\n# set up environment\npython3 -m venv venv\nsource venv/bin/activate\npip install -r requirements.txt\n\n# start talking to an AI\npython simple_conversation.py\n```\n',
    'author': 'Ajay Raj',
    'author_email': 'ajay@vocode.dev',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
